===============
Getting started
===============

Installation
------------
- Windows installers for PyScanFCS are available at the `release page <https://github.com/FCS-analysis/PyScanFCS/releases>`_.
  Note: The installer is currently broken because astropy cannot be frozen, see https://github.com/astropy/astropy/issues/7052.
- On Debian-based systems, install via ``apt-get install pyscanfcs``.
- If you have Python 3.6 installed, you may install PyScanFCS via ``pip install pyscanfcs[GUI]``.
  After the installation, type ``pyscanfcs`` in a command shell to start PyScanFCS.


Documentation
-------------
The documentation is in the process of being transferred entirely to
readthedocs.org. Currently, the it is scattered across several
places and it is most-likely outdated:

- Original LaTeX-based PDF file (outdated): https://github.com/FCS-analysis/PyScanFCS/wiki/PyScanFCS_doc.pdf
- Wiki pages: https://github.com/FCS-analysis/PyScanFCS/wiki
